@@ -4,6 +4,8 @@ class ChunkFlags(PrettyPrint):
     def __init__(self):
         self.resend = False
         self.vital = False
+    def __repr__(self):
+        return "<class: '" + str(self.__class__.__name__) + "'>: " + str(self.__dict__)
 
 # same fields for 0.6 and 0.7
 # different bit layout tho
