@@ -25,6 +25,14 @@ class Unpacker():
     def data(self) -> bytes:
         return self._data[self.idx:]
 
+    def get_raw(self, size: int = -1) -> bytes:
+        if size == -1:
+            return self.data()
+        end: int = self.idx + size
+        data: bytes = self._data[self.idx:end]
+        self.idx = end
+        return data
+
     def get_int(self) -> int:
         sign = (self.byte() >> 6) & 1
         res = self.byte() & 0x3F
@@ -81,6 +89,9 @@ def pack_int(num: int) -> bytes:
         num >>= 7 # discard 7 bits
     return bytes(res)
 
+def pack_str(data: str) -> bytes:
+    return data.encode('utf-8') + b'\x00'
+
 # TODO: optimize performance and benchmark in tests
 def unpack_int(data: bytes) -> int:
     sign = (data[0] >> 6) & 1
